#!/usr/bin/env python
# -*- coding: utf-8 -*-

def quando():
    print('30 de março a 01 de abril de 2018 -> #naoehmentira')


def onde():
    print('BandTec Digital School\nRua Haddock Lobo, 595\nSão Paulo -- Capital')


def informacoes():
    print('Acesse o site: http://pythonsudeste.org')
